unit UnitTests;
{
    UnitTestFramework
    Copyright (c) 2001, Roland Smits

    Function
    --------
    Example project that shows a unit test with all possible results.

    File Modification Record
    ------------------------
    [Date]      [By]            [Description]
    26-02-2001  Roland Smits    File created
}

interface

uses
  Windows, Contnrs,
  UnitTest;

type

  { TAllResultsTest
    ---------------
    UnitTest that shows all results a unit test can have }
  TAllResultsTest = class(TUnitTest)
  public
    procedure Register; override;
  published
    procedure SuccessCase;
    procedure FailedCase;
    procedure ExceptionCase;
    procedure ReportCase;
  end;

  { TAllResultsScript
    -----------------
    UnitTest that shows all results a unit test can have, but now only one
    UnitTestMethod is created }
  TAllResultsScript = class(TUnitTest)
  public
    procedure Register; override;
  published
    procedure Execute;
  end;

implementation

uses
  SysUtils;
  
{--- TAllResultsTest ----------------------------------------------------------}

procedure TAllResultsTest.Register;
begin
  RegisterMethod(SuccessCase);
  RegisterMethod(FailedCase);
  RegisterMethod(ExceptionCase);
  RegisterMethod(ReportCase);
end;

procedure TAllResultsTest.ExceptionCase;
begin
  raise Exception.Create('Exception thrown from ExceptionCase');
end;

procedure TAllResultsTest.FailedCase;
begin
  Check(False, 'This Check function will fail');
end;

procedure TAllResultsTest.ReportCase;
begin
  Report('Just a simple message to report');
end;

procedure TAllResultsTest.SuccessCase;
begin
  Check(True, 'This Check function will succeed');
end;

{--- TAllResultsScript --------------------------------------------------------}

procedure TAllResultsScript.Register;
begin
  RegisterMethod(Execute);
end;

procedure TAllResultsScript.Execute;
begin
  Check(True, 'This Check function will succeed');
  Check(False, 'This Check function will fail');
  Report('Just a simple message to report');
  raise Exception.Create('Exception thrown from ExceptionCase');
  Report('This will not be reported anymore, because of the exception that was raised.');
end;

end.
