unit UnitTests;
{
    UnitTestFramework
    Copyright (c) 2001, Roland Smits

    Function
    --------
    Example of database UnitTests

    This example uses the employee table of the DBDEMOS BDE alias. This
    should be avialable after a normal installation of Delphi.

    NOTE: When packing these unittests in a package (BPL) an exception is
          generated in SysUtils.pas with the message 'Application is not
          licensed to use this feature'.
          I have not a clue what this is. The solution is to package the
          unit tests in a DLL.

    File Modification Record
    ------------------------
    [Date]      [By]            [Description]
    14-05-2001  Roland Smits    File created
}

interface

uses
  Windows, Contnrs,
  UnitTest,
  DataModule;

type

  { TDBTest
    -------
    Database test }
  TDBTest = class(TUnitTest)
  private
    FDM: TDM;
  protected
    // Optional Init and Exit methods
    procedure Init; override;
    procedure Exit; override;
  public
    // Mandatory Register method
    procedure Register; override;
  published
    // Create your UnitTest Methods
    procedure AddRecord;
    procedure RemoveRecord;
  end;

implementation

uses
  SysUtils;

{--- TDBTest ------------------------------------------------------------------}

procedure TDBTest.Init;
begin
  FDM := TDM.Create(nil);
  FDM.tblEmployee.Open;
end;

procedure TDBTest.Exit;
begin
  FDM.tblEmployee.Close;
  FreeAndNil(FDM);
end;

procedure TDBTest.Register;
begin
  // Register the published UnitTest Methods
  RegisterMethod(AddRecord);
  RegisterMethod(RemoveRecord);
end;

procedure TDBTest.AddRecord;
var
  RowCount: Integer;
begin
  RowCount := FDM.tblEmployee.RecordCount;
  with FDM.tblEmployee do
  begin
    Append;
    FieldByName('EmpNo').AsInteger := 1001;
    FieldByName('LastName').AsString := 'Roland';
    FieldByName('FirstName').AsString := 'Smits';
    FieldByName('PhoneExt').AsString := '123';
    FieldByName('HireDate').AsDateTime := Now;
    FieldByName('Salary').AsFloat := 12345;
    Post;
  end;
  Check(RowCount = FDM.tblEmployee.RecordCount-1, 'Added an employee record');
end;

procedure TDBTest.RemoveRecord;
var
  RowCount: Integer;
begin
  RowCount := FDM.tblEmployee.RecordCount;
  if FDM.tblEmployee.FindKey([1001]) then
    FDM.tblEmployee.Delete;
  Check(RowCount = FDM.tblEmployee.RecordCount+1, 'Removed employee record 1001');
end;

end.
