unit UnitTests;
{
    UnitTestFramework
    Copyright (c) 2001, Roland Smits

    Function
    --------
    This example tests the TStack class of Delphi.

    This example shows two common ways to use the UnitTest Framework. The first
    way is to write a TestScript, where multiple calls to Check() are made. The
    second way is to create multiple UnitTestMethods that each test ONE single
    thing and ussually has only one call to Check().

    File Modification Record
    ------------------------
    [Date]      [By]            [Description]
    12-02-2001  Roland Smits    File created
}

interface

uses
  Windows, Contnrs,
  UnitTest;

type

  { TStackTestScript
    ----------------
    Tests the TStack class in one method called Execute
    This method contains multiple Check statements. }
  TStackTestScript = class(TUnitTest)
  public
    procedure Register; override;
  published
    procedure Execute;
  end;

  { TStackUnitTest
    --------------
    Tests the TStack class using multiple published methods that each only have
    one call to Check.
    Using the Init and Exit procedures, the FStack variable can be initialized
    and cleaned up before and after every UnitTest Method (the published test
    methods) is called. }
  TStackUnitTest = class(TUnitTest)
  private
    FStack: TStack;
  protected
    procedure Init; override;
    procedure Exit; override;
  public
    procedure Register; override;
  published
    procedure PushTest;
    procedure PopTest;
    procedure PeekTest;
  end;

implementation

uses
  SysUtils;

{--- TStackTestScript -------------------------------------------------------------}

procedure TStackTestScript.Register;
begin
  RegisterMethod(Execute);
end;

procedure TStackTestScript.Execute;
var
  Stack: TStack;
begin
  Stack := TStack.Create;
  try
    // Push test
    Stack.Push(Pointer(1));
    Stack.Push(Pointer(2));
    Stack.Push(Pointer(3));
    Check(Stack.Count = 3, 'TC01: Push test');

    // Pop Test
    Check((Integer(Stack.Pop) = 3) and (Stack.Count = 2), 'TC02: Pop Test');

    // Peek Test
    Check((Integer(Stack.Peek) = 2) and (Stack.Count = 2), 'TC03: Peek Test');

  finally
    Stack.Free;
  end;
end;

{--- TStackUnitTest --------------------------------------------------------------}

procedure TStackUnitTest.Register;
begin
  RegisterMethod(PushTest);
  RegisterMethod(PopTest);
  RegisterMethod(PeekTest);
end;

procedure TStackUnitTest.Init;
begin
  FStack := TStack.Create;
  FStack.Push(Pointer(1));
  FStack.Push(Pointer(2));
end;

procedure TStackUnitTest.Exit;
begin
  FStack.Free;
end;

procedure TStackUnitTest.PushTest;
begin
  FStack.Push(Pointer(3));
  Check( FStack.Count = 3, 'TC01: Push test' );
end;

procedure TStackUnitTest.PopTest;
begin
  Check( (Integer(FStack.Pop) = 2) and (FStack.Count = 1), 'TC02: Pop Test' );
end;

procedure TStackUnitTest.PeekTest;
begin
  Check( (Integer(FStack.Peek) = 2) and (FStack.Count = 2), 'TC03: Peek Test' );
end;

end.
